import _apply from './_apply.js';
import _createCtor from './_createCtor.js';
import _createHybrid from './_createHybrid.js';
import _createRecurry from './_createRecurry.js';
import _getHolder from './_getHolder.js';
import _replaceHolders from './_replaceHolders.js';
import _root from './_root.js';
var apply = _apply,
    createCtor = _createCtor,
    createHybrid = _createHybrid,
    createRecurry = _createRecurry,
    getHolder = _getHolder,
    replaceHolders = _replaceHolders,
    root = _root;
/**
 * Creates a function that wraps `func` to enable currying.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
 * @param {number} arity The arity of `func`.
 * @returns {Function} Returns the new wrapped function.
 */

function createCurry(func, bitmask, arity) {
  var Ctor = createCtor(func);

  function wrapper() {
    var length = arguments.length,
        args = Array(length),
        index = length,
        placeholder = getHolder(wrapper);

    while (index--) {
      args[index] = arguments[index];
    }

    var holders = length < 3 && args[0] !== placeholder && args[length - 1] !== placeholder ? [] : replaceHolders(args, placeholder);
    length -= holders.length;

    if (length < arity) {
      return createRecurry(func, bitmask, createHybrid, wrapper.placeholder, undefined, args, holders, undefined, undefined, arity - length);
    }

    var fn = this && this !== root && this instanceof wrapper ? Ctor : func;
    return apply(fn, this, args);
  }

  return wrapper;
}

var _createCurry = createCurry;
export { _createCurry as default };
//# sourceMappingURL=_createCurry.js.map
