import { __assign } from './../../external/tslib/tslib.es6.js';
import React, { useState, useRef, useEffect } from 'react';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './CollapsibleRaw.module.scss.js';
import useDynamicHeight from './useDynamicHeight.js'; // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types

var Collapsible = function (_a) {
  var _b, _c;

  var action = _a.action,
      _d = _a.animate,
      animate = _d === void 0 ? true : _d,
      children = _a.children,
      className = _a.className,
      _e = _a.classNames,
      classNames = _e === void 0 ? {
    toggler: '',
    togglerComponent: '',
    contentWrapper: ''
  } : _e,
      tabIndex = _a.tabIndex,
      _f = _a.disabled,
      disabled = _f === void 0 ? false : _f,
      metadata = _a.metadata,
      togglerComponent = _a.togglerComponent,
      _g = _a.initiallyExpanded,
      initiallyExpanded = _g === void 0 ? false : _g,
      onExpansionChange = _a.onExpansionChange;

  var _h = useState(initiallyExpanded),
      isExpanded = _h[0],
      setIsExpanded = _h[1];

  var _j = useState(),
      contentElement = _j[0],
      setContentElement = _j[1];

  var containerRef = useRef(); // this hook must be here to support dynamic response to content DOM manipulations

  var contentHeight = useDynamicHeight(contentElement);
  useEffect(function () {
    setIsExpanded(initiallyExpanded);
  }, [initiallyExpanded]);

  var toggleCollapsible = function () {
    if (disabled) return;
    setIsExpanded(function (prevIsExpanded) {
      return !prevIsExpanded;
    });

    if (onExpansionChange) {
      onExpansionChange(!isExpanded);
    }
  };

  var isSpaceOrEnter = function (e) {
    return [' ', 'Enter'].includes(e.key);
  };

  var isContainerTargeted = function (e) {
    return e.target === containerRef.current;
  };

  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.container, (_b = {}, _b[styles.disabled] = disabled, _b[styles.animate] = animate && !disabled, _b), className)
  }, parseMetadata(metadata), {
    "aria-expanded": String(isExpanded)
  }, typeof tabIndex !== 'undefined' ? {
    tabIndex: tabIndex
  } : {}, {
    role: "button",
    onKeyDown: function (e) {
      return isSpaceOrEnter(e) && isContainerTargeted(e) && e.preventDefault();
    },
    onKeyUp: function (e) {
      return isSpaceOrEnter(e) && toggleCollapsible();
    },
    ref: containerRef
  }), /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.flex, classNames.toggler)
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.togglerWrapper, classNames.togglerComponent, (_c = {}, _c[styles.togglerWrapperCursor] = !disabled, _c)),
    onClick: toggleCollapsible,
    role: "button"
  }, togglerComponent), action), /*#__PURE__*/React.createElement("fieldset", {
    className: classnames(styles.contentWrapper, classNames.contentWrapper),
    style: {
      maxHeight: isExpanded ? contentHeight : 0
    },
    ref: setContentElement,
    role: "presentation",
    onKeyUp: function (e) {
      return e.stopPropagation();
    },
    disabled: !isExpanded
  }, children));
};

export { Collapsible as default };
//# sourceMappingURL=CollapsibleRaw.js.map
